
/* Generated data (by glib-mkenums) */

#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
#error Only <epiphany/epiphany.h> can be included directly.
#endif

#ifndef EPHY_TYPE_BUILTINS_H
#define EPHY_TYPE_BUILTINS_H 1

#include <glib-object.h>

G_BEGIN_DECLS


/* --- ephy-dbus.h --- */
#define EPHY_TYPE_DBUS_BUS ephy_dbus_bus_get_type()
GType ephy_dbus_bus_get_type (void);

/* --- ephy-link.h --- */
#define EPHY_TYPE_LINK_FLAGS ephy_link_flags_get_type()
GType ephy_link_flags_get_type (void);

/* --- ephy-session.h --- */
#define EPHY_TYPE_SESSION_COMMAND ephy_session_command_get_type()
GType ephy_session_command_get_type (void);

/* --- ephy-shell.h --- */
#define EPHY_TYPE_NEW_TAB_FLAGS ephy_new_tab_flags_get_type()
GType ephy_new_tab_flags_get_type (void);

/* --- ephy-navigation-action.h --- */
#define EPHY_TYPE_NAVIGATION_DIRECTION ephy_navigation_direction_get_type()
GType ephy_navigation_direction_get_type (void);

/* --- pdm-dialog.h --- */
#define EPHY_TYPE_CLEAR_ALL_DIALOG_FLAGS pdm_clear_all_dialog_flags_get_type()
GType pdm_clear_all_dialog_flags_get_type (void);
G_END_DECLS

#endif /* EPHY_TYPE_BUILTINS_H */

/* Generated data ends here */

